package metadata

  1. Overview
  2. Docs

Module CharEncoding.NaiveSource

Basic charset conversion. The conversion routine implemented in this module is not able to detect encoding. We recommend using a library such as camomile for a more complete solution.

Sourceval convert : recode

Convert charset.