You can search for identifiers within the package.
in-package search v0.2.0
metadata
CharEncoding.Naive
Basic charset conversion. The conversion routine implemented in this module is not able to detect encoding. We recommend using a library such as camomile for a more complete solution.
val convert : recode
Convert charset.